// AlphaDoc.h
// (c) 2003 exeal

#ifndef _ALPHA_DOC_H_
#define _ALPHA_DOC_H_

#include "Ascension\EditDoc.h"
#include "AlphaTab.h"
#include "AmbientIdl.h"


using namespace Ascension;

namespace Alpha {

class CAlphaApp;
class CAlphaView;
class CAlphaEditController;

/*
///	u[N|Cg̏
enum BreakPointState {
	BPS_NONE,	/// ݒ肳ĂȂ
	BPS_ENABLE,	/// Lu[N|Cg
	BPS_DISABLE	/// u[N|Cg
};


// CAlphaDocLine class definition
/////////////////////////////////////////////////////////////////////////////

class CAlphaDocLine : public CEditDocLine {
	// f[^o
private:
	BreakPointState	m_bps;

	// \bh
public:
	BreakPointState	GetBreakPointState() const {
		return m_bps;
	}
};
*/
// CAlphaDoc class definition
/////////////////////////////////////////////////////////////////////////////

class CAlphaDoc : public Ascension::CEditDoc {
	// RXgN^
public:
	CAlphaDoc(CAlphaEditController* pController = 0);
	virtual ~CAlphaDoc();

	// \bh
public:
	void					GetAutomation(CAlphaApp& app, IDocument** ppDocument);
	CAlphaEditController*	GetController() const;

	// f[^o
protected:
	IDocument*	m_pAutomation;	// I[g[VpC^[tFCX
public:
	wstring	m_strDocType;	// KpĂ镶^Cv
};


// CAlphaDoc class inline implementation
/////////////////////////////////////////////////////////////////////////////

inline CAlphaEditController* CAlphaDoc::GetController() const {
	AssertValid();
	return reinterpret_cast<CAlphaEditController*>(m_pController);
}

}

#endif /* _ALPHA_EDIT_H_ */

/* [EOF] */